@@ -49,33 +49,33 @@ static size_t write_cb(char *data, size_t n, size_t l, void *userp)
   (void)userp;
   return n*l;
 }
-int test(char *URL)
+CURLcode test(char *URL)
 {
   CURL *easy;
+  CURLcode res = CURLE_OK;
 
-  curl_global_init(CURL_GLOBAL_DEFAULT);
+  global_init(CURL_GLOBAL_DEFAULT);
 
-  easy = curl_easy_init();
-  if(easy) {
-    CURLcode res;
-    curl_easy_setopt(easy, CURLOPT_URL, URL);
-    curl_easy_setopt(easy, CURLOPT_VERBOSE, 1L);
-    curl_easy_setopt(easy, CURLOPT_FOLLOWLOCATION, 1L);
-    /* ignores any content */
-    curl_easy_setopt(easy, CURLOPT_WRITEFUNCTION, write_cb);
+  easy_init(easy);
+  curl_easy_setopt(easy, CURLOPT_URL, URL);
+  curl_easy_setopt(easy, CURLOPT_VERBOSE, 1L);
+  curl_easy_setopt(easy, CURLOPT_FOLLOWLOCATION, 1L);
+  /* ignores any content */
+  curl_easy_setopt(easy, CURLOPT_WRITEFUNCTION, write_cb);
 
-    /* if there's a proxy set, use it */
-    if(libtest_arg2 && *libtest_arg2) {
-      curl_easy_setopt(easy, CURLOPT_PROXY, libtest_arg2);
-      curl_easy_setopt(easy, CURLOPT_HTTPPROXYTUNNEL, 1L);
-    }
-    res = curl_easy_perform(easy);
-    if(res) {
-      printf("badness: %d\n", (int)res);
-    }
-    showem(easy, CURLH_CONNECT|CURLH_HEADER|CURLH_TRAILER|CURLH_1XX);
-    curl_easy_cleanup(easy);
+  /* if there's a proxy set, use it */
+  if(libtest_arg2 && *libtest_arg2) {
+    curl_easy_setopt(easy, CURLOPT_PROXY, libtest_arg2);
+    curl_easy_setopt(easy, CURLOPT_HTTPPROXYTUNNEL, 1L);
   }
+  res = curl_easy_perform(easy);
+  if(res) {
+    printf("badness: %d\n", res);
+  }
+  showem(easy, CURLH_CONNECT|CURLH_HEADER|CURLH_TRAILER|CURLH_1XX);
+
+test_cleanup:
+  curl_easy_cleanup(easy);
   curl_global_cleanup();
-  return 0;
+  return res;
 }
